<?php
	class Stats extends CI_Model {
	
		function __construct() {
			parent::__construct();
			$this->load->library('user_agent');
		}


		/*
		 *	This function returns an array with user stats.
		 */ 
		 		
		public function getUserStats() {
			//Dummy-array to be filled
			$userStats = array(
				'agentType' => '[unknown]',
				'agentName' => '[unknown]',
				'agentVersion' => '[unknown]',
				'agentPlatform' => '[unknown]',
				'agentString' => '[unknown]'	
			);
		
			//If user is using a web browser
			if($this->agent->is_browser()) {
				$userStats['agentType'] = 'Desktop';
				$userStats['agentName'] = $this->agent->browser();
				$userStats['agentVersion'] = $this->agent->version();
			}
			//If user is using a mobile browser
			elseif ($this->agent->is_mobile()) {
				$userStats['agentType'] = 'Mobile';
				$userStats['agentName'] = $this->agent->mobile();
			}
			//If user is a robot
			elseif ($this->agent->is_robot()) {
				$userStats['agentType'] = 'Robot';
				$userStats['agentName'] = $this->agent->robot();
			}
			
			//Common stats
			$userStats['agentPlatform'] = $this->agent->platform();
			$userStats['agentString'] = $this->agent->agent_string();
			
			//Return result
			return $userStats;
		}
		
		
		/*
		 *	This function returns an array with system stats.
		 */ 		
		
		public function getSystemStats() {
			//Dummy-array to be filled
			$systemStats = array(
				'courseAmount' => '[unknown]',
				'exampleAmount' => '[unknown]',
				'quizAmount' => '[unknown]'	
			);
			
			//Get amount of courses
			$systemStats['courseAmount'] = $this->db->count_all('Courses');
			
			//Get amount of examples
			$systemStats['exampleAmount'] = $this->db->count_all('Examples');
			
			//Get amount of quizzes
			$systemStats['quizAmount'] = $this->db->count_all('Quizzes');
			
			//Return result
			return $systemStats;
		}
		
		
		/*
		 *	This function returns an array with course stats.
		 */ 
		
		public function getCourseStats($courseID) {
			//Dummy-array to be filled
			$courseStats = array(
				'exampleAmount' => '[unknown]',
				'quizAmount' => '[unknown]'	
			);
			
			$this->db->where('courseID', $courseID);
			$this->db->from('Examples');
			$courseStats['exampleAmount'] = $this->db->count_all_results();
			
			$this->db->where('courseID', $courseID);
			$this->db->from('Quizzes');
			$courseStats['quizAmount'] = $this->db->count_all_results();
			
			//Return result
			return $courseStats;	
		}
	}
?>